title:      Installation
desc:       The official docnado installation guide.
date:       2018/10/11
version:    1.0.0
template:   document
nav:        Get Setup __1__>Installation
percent:    100
authors:    enq@heinventions.com


# TLDR;

To install docnado using [pip](https://pip.pypa.io/en/stable/) use the following command:

```bash
python3 -m pip install docnado --upgrade
```

# Installation

Docnado is compatible with Microsoft Windows, Mac OSX, and most GNU/Linux distributions.

Docnado requires `Python 3.6` or higher to be installed on your system. This should be available through your systems package manager or via direct download at [www.python.org](https://www.python.org). You will also need to install the pip package management system, available at [pip.pypa.io](https://pip.pypa.io/en/stable/).

To check if you have `Python 3.6` and `Pip` installed, from your command prompt, run:

```bash
$ python3 --version
Python 3.6.6

$ python3 -m pip -V
pip 9.0.1 from /usr/lib/python3/dist-packages (python 3.6)
```

You're ready to install docnado from your command line with:

```bash
python3 -m pip install docnado --upgrade
```

Please note that if any errors occur you will have to refer to the `Python3` and `Pip` installation and troubleshooting guides for your platform.
{: .info}

![Installation Guide](https://youtu.be/UQkIgTbbado)
